@@ -3,7 +3,7 @@
 package Text::LineFold;
 require 5.008;
 
-=encoding utf-8
+=encoding utf8
 
 =head1 NAME
 
@@ -39,12 +39,12 @@ our @ISA = qw(Exporter Unicode::LineBreak);
 use Carp qw(croak carp);
 use Encode qw(is_utf8);
 use MIME::Charset;
-use Unicode::LineBreak qw(:all);
+use Unicode::LineBreak qw(getcontext);
 
 ### Globals
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-our $VERSION = '0.005';
+our $VERSION = '0.001';
 
 ### Public Configuration Attributes
 our $Config = {
@@ -265,7 +265,7 @@ sub config {
     ## Context
     Unicode::LineBreak::config($self,
 			       Context =>
-			       context(Charset => $self->{Charset},
+			       getcontext(Charset => $self->{Charset},
 					  Language => $self->{Language}));
 }
 
@@ -415,13 +415,13 @@ sub unfold {
 			my $i = length $l;
 			do {
 			    $i--;
-			    $b_cls = $self->lbclass(substr($l, $i));
-			} while ($b_cls == LB_CM and 0 < $i);
-			$b_cls = LB_AL if $b_cls == LB_CM or $b_cls == LB_SP;
-			$a_cls = $self->lbclass($n);
-			$a_cls = LB_AL if $a_cls == LB_CM;
+			    $b_cls = $self->getlbclass(substr($l, $i));
+			} while ($b_cls eq 'CM' and 0 < $i);
+			$b_cls = 'AL' if $b_cls eq 'CM' or $b_cls eq 'SP';
+			$a_cls = $self->getlbclass($n);
+			$a_cls = 'AL' if $a_cls eq 'CM';
 
-			if ($self->lbrule($b_cls, $a_cls) == INDIRECT) {
+			if ($self->getlbrule($b_cls, $a_cls) eq 'INDIRECT') {
 			    $result .= ' ';
 			}
 		    }
